PyRates
=============
PyRates supports conversion between 54 currency rates
-------
Can be used as:
- Package/Module
- CLI
- GUI

The rates are fetched by webscraping x-rates.com and saved locally

In order to keep get-requests to a minimum, rates are only updated if they are older than 30 minutes

The base currency is by default: Euro. Work in progress to let the user change the base currency at will

# [Documentation](https://github.com/Lindeneg/pyrates-cl/tree/0.2/docs)